DateDurationUnit

Enum DateDurationUnit 

pub enum DateDurationUnit {
    Years,
    Months,
    Weeks,
    Days,
}
A “duration unit” used to specify the minimum or maximum duration of time to care about

🚧 This code is considered unstable; it may change at any time, in breaking or non-breaking ways, including in SemVer minor releases. Do not use this type unless you are prepared for things to occasionally break.

Graduation tracking issue: issue #3964.

Enabled with the unstable Cargo feature.

Variants



Years

Duration in years



Months

Duration in months



Weeks

Duration in weeks



Days

Duration in days